@@ -16,18 +16,24 @@
  * 02110-1301, USA.
  */
 
+#include <cairomm/cairommconfig.h>
 #include <cairomm/context.h>
 #include <cairomm/private.h>
 #include <cairomm/surface.h>
 #include <cairomm/win32_surface.h>
 #include <cairomm/xlib_surface.h>
+#include <cairomm/quartz_surface.h>
 
 /* M_PI is defined in math.h in the case of Microsoft Visual C++ */
 #if defined(_MSC_VER)
 #define _USE_MATH_DEFINES
-#include <math.h>
 #endif 
 
+/* Solaris et. al. need math.h for M_PI too */
+#ifdef HAVE_MATH_H
+# include <math.h>
+#endif
+
 namespace Cairo
 {
 
